OMS CMS
=======
[![Build Status](https://travis-ci.org/DJWOMS/oms_cms.svg?branch=master)](https://travis-ci.org/DJWOMS/oms_cms)
[![Coverage Status](https://coveralls.io/repos/github/DJWOMS/oms_cms/badge.svg?branch=master)](https://coveralls.io/github/DJWOMS/oms_cms?branch=master)
[![License](https://img.shields.io/pypi/l/oms-cms)](https://opensource.org/licenses/BSD-3-Clause)
[![Version](https://img.shields.io/pypi/v/oms-cms)](https://pypi.org/project/oms-cms/) 
[![Slack](https://img.shields.io/badge/Slack-chat-green)](https://join.slack.com/t/oms-cms/) 

[Website](https://oms-cms.site/en/)

[Documentation](https://oms-cms.readthedocs.io/ru/latest/)

* Python => 3.6
* Django => 2

OMS CMS is designed for a wide range of developers.

The system is open source, written using the Django framework in the Python programming language.

This CMS was designed by developers for a quick start and easy scalability.
OMS allows you to easily integrate with other django applications and use them immediately,
Or create new compatible applications!

This cms allows you to make a website in minutes.
You can use the basic template or download from the official site.

Modules
-------
* Pages
* News
   * Categories
   * Articles
   * Tags
* Comments
* Contacts
* Info block
* Languages, multilingualism
* Menu
* SEO
* Partners
* Search
* Links to social networks

Installation:
-------------

Create virtual environment ::

    python -m venv venv
    
Activate virtual environment

Install CMS ::

    pip install oms-cms
    
Create Project ::

    oms-start
    
   
[Development](https://github.com/DJWOMS/oms_cms/wiki/Development)

__________________________________________________________

[Сайт](https://oms-cms.site)

[Документация](https://oms-cms.readthedocs.io/ru/latest/)
 
* Python => 3.6
* Django => 2

OMS CMS создана для широкого круга разработчиков. 

Система имеет открытый исходный код, написана с использованием фреймворка Django на языке программирования Python. 

Данная CMS была задумана разработчиками для быстрого старта и легкой масштабируемости. 
OMS позволяет без трудностей интегрироваться с другими приложениями django и сразу же использовать их, 
либо создавать новые совместимые приложения!

Данная cms позволяет сделать сайт за считанные минуту. 
Вы можете использовать базовый шаблон или скачать с официального сайта.

Модули
------
* Страницы
* Новости
   * Категории
   * Статьи
   * Теги
* Комментарии
* Контакты
* Инфо блк
* Языки \ мультиязычность
* Меню
* SEO
* Партнеры
* Поиск
* Ссылки на социальные сети

Установка:
----------

Создать виртуальное окружение ::

    python -m venv venv
    
Активировать виртуальное окружение

Установить CMS ::

    pip install oms-cms
    
Создать проект ::
    
    oms-start


[Разработка](https://github.com/DJWOMS/oms_cms/wiki/Development)
